# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bilibili/app/dynamic/v1/dynamic.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from bilireq.grpc.protos.bilibili.app.archive.middleware.v1 import preload_pb2 as bilibili_dot_app_dot_archive_dot_middleware_dot_v1_dot_preload__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%bilibili/app/dynamic/v1/dynamic.proto\x12\x17\x62ilibili.app.dynamic.v1\x1a\x30\x62ilibili/app/archive/middleware/v1/preload.proto\"\x07\n\x05NoReq\"\t\n\x07NoReply\"\xbf\x01\n\x0b\x44ynVideoReq\x12\x16\n\x0eteenagers_mode\x18\x01 \x01(\x05\x12\x17\n\x0fupdate_baseline\x18\x02 \x01(\t\x12\x0e\n\x06offset\x18\x03 \x01(\t\x12\x0c\n\x04page\x18\x04 \x01(\x05\x12\x14\n\x0crefresh_type\x18\x05 \x01(\x05\x12\n\n\x02qn\x18\x06 \x01(\x05\x12\r\n\x05\x66nver\x18\x07 \x01(\x05\x12\r\n\x05\x66nval\x18\x08 \x01(\x05\x12\x12\n\nforce_host\x18\t \x01(\x05\x12\r\n\x05\x66ourk\x18\n \x01(\x05\"\x9d\x01\n\x10\x44ynVideoReqReply\x12\x32\n\x04list\x18\x01 \x03(\x0b\x32$.bilibili.app.dynamic.v1.DynamicItem\x12\x12\n\nupdate_num\x18\x02 \x01(\x05\x12\x16\n\x0ehistory_offset\x18\x03 \x01(\t\x12\x17\n\x0fupdate_baseline\x18\x04 \x01(\t\x12\x10\n\x08has_more\x18\x05 \x01(\x05\"\xb4\x01\n\x0b\x44ynamicItem\x12\x11\n\tcard_type\x18\x01 \x01(\t\x12\x11\n\titem_type\x18\x02 \x01(\t\x12\x30\n\x07modules\x18\x03 \x03(\x0b\x32\x1f.bilibili.app.dynamic.v1.Module\x12\x12\n\ndyn_id_str\x18\x04 \x01(\t\x12\x17\n\x0forig_dyn_id_str\x18\x05 \x01(\t\x12\x0e\n\x06r_type\x18\x06 \x01(\x05\x12\x10\n\x08has_fold\x18\x07 \x01(\x05\"\xf7\x05\n\x06Module\x12\x13\n\x0bmodule_type\x18\x01 \x01(\t\x12:\n\x0bmodule_fold\x18\x02 \x01(\x0b\x32#.bilibili.app.dynamic.v1.ModuleFoldH\x00\x12>\n\rmodule_author\x18\x03 \x01(\x0b\x32%.bilibili.app.dynamic.v1.ModuleAuthorH\x00\x12@\n\x0emodule_dynamic\x18\x04 \x01(\x0b\x32&.bilibili.app.dynamic.v1.ModuleDynamicH\x00\x12<\n\x0cmodule_state\x18\x05 \x01(\x0b\x32$.bilibili.app.dynamic.v1.ModuleStateH\x00\x12@\n\x0emodule_forward\x18\x06 \x01(\x0b\x32&.bilibili.app.dynamic.v1.ModuleForwardH\x00\x12>\n\rmodule_extend\x18\x07 \x01(\x0b\x32%.bilibili.app.dynamic.v1.ModuleExtendH\x00\x12@\n\x0emodule_dispute\x18\x08 \x01(\x0b\x32&.bilibili.app.dynamic.v1.ModuleDisputeH\x00\x12:\n\x0bmodule_desc\x18\t \x01(\x0b\x32#.bilibili.app.dynamic.v1.ModuleDescH\x00\x12\x42\n\x0fmodule_likeUser\x18\n \x01(\x0b\x32\'.bilibili.app.dynamic.v1.ModuleLikeUserH\x00\x12\x41\n\rmodule_upList\x18\x0b \x01(\x0b\x32(.bilibili.app.dynamic.v1.ModuleDynUpListH\x00\x12\x46\n\x11module_followList\x18\x0c \x01(\x0b\x32).bilibili.app.dynamic.v1.ModuleFollowListH\x00\x42\r\n\x0bmodule_item\"\xaf\x01\n\nModuleFold\x12\x11\n\tfold_type\x18\x01 \x01(\x05\x12\x0c\n\x04text\x18\x02 \x01(\t\x12\x10\n\x08\x66old_ids\x18\x03 \x01(\t\x12\x35\n\nfold_users\x18\x04 \x03(\x0b\x32!.bilibili.app.dynamic.v1.UserInfo\x12\x37\n\x0c\x66old_type_v2\x18\x05 \x01(\x0e\x32!.bilibili.app.dynamic.v1.FoldType\"\xa5\x01\n\x0cModuleAuthor\x12\n\n\x02id\x18\x01 \x01(\x03\x12\x18\n\x10ptime_label_text\x18\x02 \x01(\t\x12\x31\n\x06\x61uthor\x18\x03 \x01(\x0b\x32!.bilibili.app.dynamic.v1.UserInfo\x12<\n\rdecorate_card\x18\x04 \x01(\x0b\x32%.bilibili.app.dynamic.v1.DecorateCard\"9\n\rModuleDispute\x12\r\n\x05title\x18\x01 \x01(\t\x12\x0c\n\x04\x64\x65sc\x18\x02 \x01(\t\x12\x0b\n\x03uri\x18\x03 \x01(\t\"@\n\nModuleDesc\x12\x32\n\x04\x64\x65sc\x18\x01 \x03(\x0b\x32$.bilibili.app.dynamic.v1.Description\"\x9e\x02\n\rModuleDynamic\x12\x11\n\tcard_type\x18\x01 \x01(\t\x12\x34\n\x08\x63\x61rd_ugc\x18\x02 \x01(\x0b\x32 .bilibili.app.dynamic.v1.CardUGCH\x00\x12\x34\n\x08\x63\x61rd_pgc\x18\x03 \x01(\x0b\x32 .bilibili.app.dynamic.v1.CardPGCH\x00\x12\x43\n\x10\x63\x61rd_curr_season\x18\x04 \x01(\x0b\x32\'.bilibili.app.dynamic.v1.CardCurrSeasonH\x00\x12\x41\n\x0f\x63\x61rd_curr_batch\x18\x05 \x01(\x0b\x32&.bilibili.app.dynamic.v1.CardCurrBatchH\x00\x42\x06\n\x04\x63\x61rd\"]\n\x0eModuleLikeUser\x12\x35\n\nlike_users\x18\x01 \x03(\x0b\x32!.bilibili.app.dynamic.v1.LikeUser\x12\x14\n\x0c\x64isplay_text\x18\x02 \x01(\t\"\x98\x01\n\x0bModuleState\x12\x0e\n\x06repost\x18\x01 \x01(\x05\x12\x0c\n\x04like\x18\x02 \x01(\x05\x12\r\n\x05reply\x18\x03 \x01(\x05\x12\x34\n\tlike_info\x18\x04 \x01(\x0b\x32!.bilibili.app.dynamic.v1.LikeInfo\x12\x12\n\nno_comment\x18\x05 \x01(\x08\x12\x12\n\nno_forward\x18\x06 \x01(\x08\"T\n\rModuleForward\x12\x11\n\tcard_type\x18\x01 \x01(\t\x12\x30\n\x07modules\x18\x02 \x03(\x0b\x32\x1f.bilibili.app.dynamic.v1.Module\"\xd5\x02\n\x07\x43\x61rdUGC\x12\r\n\x05title\x18\x01 \x01(\t\x12\r\n\x05\x63over\x18\x02 \x01(\t\x12\x0b\n\x03uri\x18\x03 \x01(\t\x12\x19\n\x11\x63over_left_text_1\x18\x04 \x01(\t\x12\x19\n\x11\x63over_left_text_2\x18\x05 \x01(\t\x12\x19\n\x11\x63over_left_text_3\x18\x06 \x01(\t\x12\x0c\n\x04\x61vid\x18\x07 \x01(\x03\x12\x0b\n\x03\x63id\x18\x08 \x01(\x03\x12\x36\n\nmedia_type\x18\t \x01(\x0e\x32\".bilibili.app.dynamic.v1.MediaType\x12\x35\n\tdimension\x18\n \x01(\x0b\x32\".bilibili.app.dynamic.v1.Dimension\x12\x32\n\x05\x62\x61\x64ge\x18\x0b \x03(\x0b\x32#.bilibili.app.dynamic.v1.VideoBadge\x12\x10\n\x08\x63\x61n_play\x18\x0c \x01(\x05\"\xf6\x03\n\x07\x43\x61rdPGC\x12\r\n\x05title\x18\x01 \x01(\t\x12\r\n\x05\x63over\x18\x02 \x01(\t\x12\x0b\n\x03uri\x18\x03 \x01(\t\x12\x19\n\x11\x63over_left_text_1\x18\x04 \x01(\t\x12\x19\n\x11\x63over_left_text_2\x18\x05 \x01(\t\x12\x19\n\x11\x63over_left_text_3\x18\x06 \x01(\t\x12\x0b\n\x03\x63id\x18\x07 \x01(\x03\x12\x11\n\tseason_id\x18\x08 \x01(\x03\x12\x0c\n\x04\x65pid\x18\t \x01(\x03\x12\x0b\n\x03\x61id\x18\n \x01(\x03\x12\x36\n\nmedia_type\x18\x0b \x01(\x0e\x32\".bilibili.app.dynamic.v1.MediaType\x12\x37\n\x08sub_type\x18\x0c \x01(\x0e\x32%.bilibili.app.dynamic.v1.VideoSubType\x12\x12\n\nis_preview\x18\r \x01(\x05\x12\x35\n\tdimension\x18\x0e \x01(\x0b\x32\".bilibili.app.dynamic.v1.Dimension\x12\x32\n\x05\x62\x61\x64ge\x18\x0f \x03(\x0b\x32#.bilibili.app.dynamic.v1.VideoBadge\x12\x10\n\x08\x63\x61n_play\x18\x10 \x01(\x05\x12\x32\n\x06season\x18\x11 \x01(\x0b\x32\".bilibili.app.dynamic.v1.PGCSeason\"\x8d\x01\n\x0e\x43\x61rdCurrSeason\x12\r\n\x05title\x18\x01 \x01(\t\x12\r\n\x05\x63over\x18\x02 \x01(\t\x12\x0b\n\x03uri\x18\x03 \x01(\t\x12\x0e\n\x06text_1\x18\x04 \x01(\t\x12\x0c\n\x04\x64\x65sc\x18\x05 \x01(\t\x12\x32\n\x05\x62\x61\x64ge\x18\x06 \x01(\x0b\x32#.bilibili.app.dynamic.v1.VideoBadge\"\x8e\x01\n\rCardCurrBatch\x12\r\n\x05title\x18\x01 \x01(\t\x12\r\n\x05\x63over\x18\x02 \x01(\t\x12\x0b\n\x03uri\x18\x03 \x01(\t\x12\x0e\n\x06text_1\x18\x04 \x01(\t\x12\x0e\n\x06text_2\x18\x05 \x01(\t\x12\x32\n\x05\x62\x61\x64ge\x18\x06 \x01(\x0b\x32#.bilibili.app.dynamic.v1.VideoBadge\"\xb6\x01\n\nVideoBadge\x12\x0c\n\x04text\x18\x01 \x01(\t\x12\x12\n\ntext_color\x18\x02 \x01(\t\x12\x18\n\x10text_color_night\x18\x03 \x01(\t\x12\x10\n\x08\x62g_color\x18\x04 \x01(\t\x12\x16\n\x0e\x62g_color_night\x18\x05 \x01(\t\x12\x14\n\x0c\x62order_color\x18\x06 \x01(\t\x12\x1a\n\x12\x62order_color_night\x18\x07 \x01(\t\x12\x10\n\x08\x62g_style\x18\x08 \x01(\x05\":\n\tDimension\x12\x0e\n\x06height\x18\x01 \x01(\x03\x12\r\n\x05width\x18\x02 \x01(\x03\x12\x0e\n\x06rotate\x18\x03 \x01(\x03\"?\n\x0cModuleExtend\x12/\n\x06\x65xtend\x18\x01 \x03(\x0b\x32\x1f.bilibili.app.dynamic.v1.Extend\"\x9a\x02\n\x06\x45xtend\x12\x0c\n\x04type\x18\x01 \x01(\t\x12?\n\x0e\x65xt_info_topic\x18\x02 \x01(\x0b\x32%.bilibili.app.dynamic.v1.ExtInfoTopicH\x00\x12;\n\x0c\x65xt_info_lbs\x18\x03 \x01(\x0b\x32#.bilibili.app.dynamic.v1.ExtInfoLBSH\x00\x12;\n\x0c\x65xt_info_hot\x18\x04 \x01(\x0b\x32#.bilibili.app.dynamic.v1.ExtInfoHotH\x00\x12=\n\rext_info_game\x18\x05 \x01(\x0b\x32$.bilibili.app.dynamic.v1.ExtInfoGameH\x00\x42\x08\n\x06\x65xtend\"7\n\x0b\x45xtInfoGame\x12\r\n\x05title\x18\x01 \x01(\t\x12\x0b\n\x03uri\x18\x02 \x01(\t\x12\x0c\n\x04icon\x18\x03 \x01(\t\"8\n\x0c\x45xtInfoTopic\x12\r\n\x05title\x18\x01 \x01(\t\x12\x0b\n\x03uri\x18\x02 \x01(\t\x12\x0c\n\x04icon\x18\x03 \x01(\t\"H\n\nExtInfoLBS\x12\r\n\x05title\x18\x01 \x01(\t\x12\x0b\n\x03uri\x18\x02 \x01(\t\x12\x0c\n\x04icon\x18\x03 \x01(\t\x12\x10\n\x08poi_type\x18\x04 \x01(\x05\"6\n\nExtInfoHot\x12\r\n\x05title\x18\x01 \x01(\t\x12\x0b\n\x03uri\x18\x02 \x01(\t\x12\x0c\n\x04icon\x18\x03 \x01(\t\"V\n\x08LikeInfo\x12\x39\n\tanimation\x18\x01 \x01(\x0b\x32&.bilibili.app.dynamic.v1.LikeAnimation\x12\x0f\n\x07is_like\x18\x02 \x01(\x05\"3\n\x08LikeUser\x12\x0b\n\x03uid\x18\x01 \x01(\x03\x12\r\n\x05uname\x18\x02 \x01(\t\x12\x0b\n\x03uri\x18\x03 \x01(\t\"O\n\rLikeAnimation\x12\r\n\x05\x62\x65gin\x18\x01 \x01(\t\x12\x0c\n\x04proc\x18\x02 \x01(\t\x12\x0b\n\x03\x65nd\x18\x03 \x01(\t\x12\x14\n\x0clike_icon_id\x18\x04 \x01(\x03\"^\n\x0b\x44\x65scription\x12\x0c\n\x04text\x18\x01 \x01(\t\x12\x0c\n\x04type\x18\x02 \x01(\t\x12\x0b\n\x03uri\x18\x03 \x01(\t\x12\x12\n\nemoji_type\x18\x04 \x01(\t\x12\x12\n\ngoods_type\x18\x05 \x01(\t\"q\n\x0c\x44\x65\x63orateCard\x12\n\n\x02id\x18\x01 \x01(\x03\x12\x10\n\x08\x63\x61rd_url\x18\x02 \x01(\t\x12\x10\n\x08jump_url\x18\x03 \x01(\t\x12\x31\n\x03\x66\x61n\x18\x04 \x01(\x0b\x32$.bilibili.app.dynamic.v1.DecoCardFan\"<\n\x0b\x44\x65\x63oCardFan\x12\x0e\n\x06is_fan\x18\x01 \x01(\x05\x12\x0e\n\x06number\x18\x02 \x01(\x05\x12\r\n\x05\x63olor\x18\x03 \x01(\t\"\xc9\x02\n\x08UserInfo\x12\x0b\n\x03mid\x18\x01 \x01(\x03\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04\x66\x61\x63\x65\x18\x03 \x01(\t\x12\x39\n\x08official\x18\x04 \x01(\x0b\x32\'.bilibili.app.dynamic.v1.OfficialVerify\x12-\n\x03vip\x18\x05 \x01(\x0b\x32 .bilibili.app.dynamic.v1.VipInfo\x12/\n\x04live\x18\x06 \x01(\x0b\x32!.bilibili.app.dynamic.v1.LiveInfo\x12\x0b\n\x03uri\x18\x07 \x01(\t\x12\x35\n\x07pendant\x18\x08 \x01(\x0b\x32$.bilibili.app.dynamic.v1.UserPendant\x12\x35\n\tnameplate\x18\t \x01(\x0b\x32\".bilibili.app.dynamic.v1.Nameplate\"l\n\tNameplate\x12\x0b\n\x03nid\x18\x01 \x01(\x03\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\r\n\x05image\x18\x03 \x01(\t\x12\x13\n\x0bimage_small\x18\x04 \x01(\t\x12\r\n\x05level\x18\x05 \x01(\t\x12\x11\n\tcondition\x18\x06 \x01(\t\"G\n\x0bUserPendant\x12\x0b\n\x03pid\x18\x01 \x01(\x03\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\r\n\x05image\x18\x03 \x01(\t\x12\x0e\n\x06\x65xpire\x18\x04 \x01(\x03\">\n\x0eOfficialVerify\x12\x0c\n\x04type\x18\x01 \x01(\x05\x12\x0c\n\x04\x64\x65sc\x18\x02 \x01(\t\x12\x10\n\x08is_atten\x18\x03 \x01(\x05\"\x7f\n\x07VipInfo\x12\x0c\n\x04Type\x18\x01 \x01(\x05\x12\x0e\n\x06status\x18\x02 \x01(\x05\x12\x10\n\x08\x64ue_date\x18\x03 \x01(\x03\x12\x30\n\x05label\x18\x04 \x01(\x0b\x32!.bilibili.app.dynamic.v1.VipLabel\x12\x12\n\ntheme_type\x18\x05 \x01(\x05\"\x18\n\x08VipLabel\x12\x0c\n\x04path\x18\x01 \x01(\t\"*\n\x08LiveInfo\x12\x11\n\tis_living\x18\x01 \x01(\x05\x12\x0b\n\x03uri\x18\x02 \x01(\t\"\x89\x01\n\rDynDetailsReq\x12\x16\n\x0eteenagers_mode\x18\x01 \x01(\x05\x12\x13\n\x0b\x64ynamic_ids\x18\x02 \x01(\t\x12\n\n\x02qn\x18\x03 \x01(\x05\x12\r\n\x05\x66nver\x18\x04 \x01(\x05\x12\r\n\x05\x66nval\x18\x05 \x01(\x05\x12\x12\n\nforce_host\x18\x06 \x01(\x05\x12\r\n\x05\x66ourk\x18\x07 \x01(\x05\"E\n\x0f\x44ynDetailsReply\x12\x32\n\x04list\x18\x01 \x03(\x0b\x32$.bilibili.app.dynamic.v1.DynamicItem\"\xe9\x02\n\tSVideoReq\x12\x0b\n\x03oid\x18\x01 \x01(\x03\x12\x31\n\x04type\x18\x02 \x01(\x0e\x32#.bilibili.app.dynamic.v1.SVideoType\x12\x0e\n\x06offset\x18\x03 \x01(\t\x12\n\n\x02qn\x18\x04 \x01(\x05\x12\r\n\x05\x66nver\x18\x05 \x01(\x05\x12\r\n\x05\x66nval\x18\x06 \x01(\x05\x12\x12\n\nforce_host\x18\x07 \x01(\x05\x12\r\n\x05\x66ourk\x18\x08 \x01(\x05\x12\r\n\x05spmid\x18\t \x01(\t\x12\x12\n\nfrom_spmid\x18\n \x01(\t\x12\x44\n\x0eplayer_preload\x18\x0b \x01(\x0b\x32,.bilibili.app.dynamic.v1.PlayerPreloadParams\x12\x11\n\tfocus_aid\x18\x0c \x01(\x03\x12\x43\n\x0bplayer_args\x18\r \x01(\x0b\x32..bilibili.app.archive.middleware.v1.PlayerArgs\"\x93\x01\n\x0bSVideoReply\x12\x31\n\x04list\x18\x01 \x03(\x0b\x32#.bilibili.app.dynamic.v1.SVideoItem\x12\x0e\n\x06offset\x18\x02 \x01(\t\x12\x10\n\x08has_more\x18\x03 \x01(\x05\x12/\n\x03top\x18\x04 \x01(\x0b\x32\".bilibili.app.dynamic.v1.SVideoTop\"(\n\tSVideoTop\x12\r\n\x05Title\x18\x01 \x01(\t\x12\x0c\n\x04\x44\x65sc\x18\x02 \x01(\t\"b\n\x13PlayerPreloadParams\x12\n\n\x02qn\x18\x01 \x01(\x05\x12\r\n\x05\x66nver\x18\x02 \x01(\x05\x12\r\n\x05\x66nval\x18\x03 \x01(\x05\x12\x12\n\nforce_host\x18\x04 \x01(\x05\x12\r\n\x05\x66ourk\x18\x05 \x01(\x05\"z\n\nSVideoItem\x12\x11\n\tcard_type\x18\x01 \x01(\t\x12\x36\n\x07modules\x18\x02 \x03(\x0b\x32%.bilibili.app.dynamic.v1.SVideoModule\x12\x12\n\ndyn_id_str\x18\x03 \x01(\t\x12\r\n\x05index\x18\x04 \x01(\x03\"\xc2\x02\n\x0cSVideoModule\x12\x13\n\x0bmodule_type\x18\x01 \x01(\t\x12\x44\n\rmodule_author\x18\x02 \x01(\x0b\x32+.bilibili.app.dynamic.v1.SVideoModuleAuthorH\x00\x12\x44\n\rmodule_player\x18\x03 \x01(\x0b\x32+.bilibili.app.dynamic.v1.SVideoModulePlayerH\x00\x12@\n\x0bmodule_desc\x18\x04 \x01(\x0b\x32).bilibili.app.dynamic.v1.SVideoModuleDescH\x00\x12@\n\x0bmodule_stat\x18\x05 \x01(\x0b\x32).bilibili.app.dynamic.v1.SVideoModuleStatH\x00\x42\r\n\x0bmodule_item\"r\n\x12SVideoModuleAuthor\x12\x0b\n\x03mid\x18\x01 \x01(\x03\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04\x66\x61\x63\x65\x18\x03 \x01(\t\x12\x10\n\x08pub_desc\x18\x04 \x01(\t\x12\x14\n\x0cis_attention\x18\x05 \x01(\x05\x12\x0b\n\x03uri\x18\x06 \x01(\t\"\xa2\x01\n\x12SVideoModulePlayer\x12\r\n\x05title\x18\x01 \x01(\t\x12\r\n\x05\x63over\x18\x02 \x01(\t\x12\x0b\n\x03uri\x18\x03 \x01(\t\x12\x0b\n\x03\x61id\x18\x04 \x01(\x03\x12\x0b\n\x03\x63id\x18\x05 \x01(\x03\x12\x10\n\x08\x64uration\x18\x06 \x01(\x03\x12\x35\n\tdimension\x18\x07 \x01(\x0b\x32\".bilibili.app.dynamic.v1.Dimension\"-\n\x10SVideoModuleDesc\x12\x0c\n\x04text\x18\x01 \x01(\t\x12\x0b\n\x03uri\x18\x02 \x01(\t\"\x86\x01\n\x10SVideoModuleStat\x12:\n\tstat_info\x18\x01 \x03(\x0b\x32\'.bilibili.app.dynamic.v1.SVideoStatInfo\x12\x36\n\nshare_info\x18\x02 \x01(\x0b\x32\".bilibili.app.dynamic.v1.ShareInfo\"J\n\x0eSVideoStatInfo\x12\x0c\n\x04icon\x18\x01 \x01(\x05\x12\x0b\n\x03num\x18\x02 \x01(\x03\x12\x10\n\x08selected\x18\x03 \x01(\x05\x12\x0b\n\x03uri\x18\x04 \x01(\t\"q\n\tShareInfo\x12\x0b\n\x03\x61id\x18\x01 \x01(\x03\x12\x0c\n\x04\x62vid\x18\x02 \x01(\t\x12\r\n\x05title\x18\x03 \x01(\t\x12\x10\n\x08subtitle\x18\x04 \x01(\t\x12\r\n\x05\x63over\x18\x05 \x01(\t\x12\x0b\n\x03mid\x18\x06 \x01(\x03\x12\x0c\n\x04name\x18\x07 \x01(\t\"#\n\tDynTabReq\x12\x16\n\x0eteenagers_mode\x18\x01 \x01(\x05\"?\n\x0b\x44ynTabReply\x12\x30\n\x07\x64yn_tab\x18\x01 \x03(\x0b\x32\x1f.bilibili.app.dynamic.v1.DynTab\"\xe7\x01\n\x06\x44ynTab\x12\r\n\x05title\x18\x01 \x01(\t\x12\x0b\n\x03uri\x18\x02 \x01(\t\x12\x0e\n\x06\x62ubble\x18\x03 \x01(\t\x12\x11\n\tred_point\x18\x04 \x01(\x05\x12\x0f\n\x07\x63ity_id\x18\x05 \x01(\x03\x12\x10\n\x08is_popup\x18\x06 \x01(\x05\x12-\n\x05popup\x18\x07 \x01(\x0b\x32\x1e.bilibili.app.dynamic.v1.Popup\x12\x12\n\ndefaultTab\x18\x08 \x01(\x08\x12\x11\n\tsub_title\x18\t \x01(\t\x12\x0e\n\x06\x61nchor\x18\n \x01(\t\x12\x15\n\rinternal_test\x18\x0b \x01(\t\"1\n\x05Popup\x12\r\n\x05title\x18\x01 \x01(\t\x12\x0c\n\x04\x64\x65sc\x18\x02 \x01(\t\x12\x0b\n\x03uri\x18\x03 \x01(\t\"%\n\x13\x44ynOurCitySwitchReq\x12\x0e\n\x06switch\x18\x01 \x01(\x05\"\x8b\x03\n\rDynOurCityReq\x12\x0f\n\x07\x63ity_id\x18\x01 \x01(\x03\x12\x0b\n\x03lat\x18\x02 \x01(\x01\x12\x0b\n\x03lng\x18\x03 \x01(\x01\x12\x0e\n\x06offset\x18\x04 \x01(\t\x12\x11\n\tpage_size\x18\x05 \x01(\x05\x12\x16\n\x0eteenagers_mode\x18\x06 \x01(\x05\x12\n\n\x02qn\x18\x07 \x01(\x05\x12\r\n\x05\x66nver\x18\x08 \x01(\x05\x12\r\n\x05\x66nval\x18\t \x01(\x05\x12\x12\n\nforce_host\x18\n \x01(\x05\x12\r\n\x05\x66ourk\x18\x0b \x01(\x05\x12\x11\n\tlbs_state\x18\x0c \x01(\x05\x12\x14\n\x0crefresh_city\x18\r \x01(\r\x12\x32\n\x08\x65xp_conf\x18\x0e \x01(\x0b\x32 .bilibili.app.dynamic.v1.ExpConf\x12\x43\n\x0bplayer_args\x18\x0f \x01(\x0b\x32..bilibili.app.archive.middleware.v1.PlayerArgs\x12\x11\n\tcity_code\x18\x10 \x01(\x03\x12\x12\n\nbuild_time\x18\x11 \x01(\x03\"I\n\x07\x45xpConf\x12\x12\n\nexp_enable\x18\x01 \x01(\x05\x12*\n\x04\x65xps\x18\x02 \x03(\x0b\x32\x1c.bilibili.app.dynamic.v1.Exp\"*\n\x03\x45xp\x12\x10\n\x08\x65xp_name\x18\x01 \x01(\t\x12\x11\n\texp_group\x18\x02 \x01(\t\"\xca\x01\n\x0f\x44ynOurCityReply\x12\x0e\n\x06offset\x18\x01 \x01(\t\x12\x10\n\x08has_more\x18\x02 \x01(\x05\x12\r\n\x05style\x18\x03 \x01(\x05\x12\x11\n\ttop_label\x18\x04 \x01(\t\x12\x35\n\x04list\x18\x05 \x03(\x0b\x32\'.bilibili.app.dynamic.v1.DynOurCityItem\x12\x18\n\x10top_button_label\x18\x06 \x01(\t\x12\x0f\n\x07\x63ity_id\x18\x07 \x01(\x05\x12\x11\n\tcity_name\x18\x08 \x01(\t\"\x9d\x01\n\x0e\x44ynOurCityItem\x12\x11\n\tcard_type\x18\x01 \x01(\t\x12\x0e\n\x06\x64yn_id\x18\x02 \x01(\x03\x12\x0b\n\x03uri\x18\x03 \x01(\t\x12:\n\x07modules\x18\x04 \x03(\x0b\x32).bilibili.app.dynamic.v1.DynOurCityModule\x12\x0b\n\x03rid\x18\x05 \x01(\x03\x12\x12\n\ndebug_info\x18\x06 \x01(\t\"\xd8\x02\n\x10\x44ynOurCityModule\x12\x13\n\x0bmodule_type\x18\x01 \x01(\t\x12\x46\n\x0cmodule_cover\x18\x02 \x01(\x0b\x32..bilibili.app.dynamic.v1.DynOurCityModuleCoverH\x00\x12\x44\n\x0bmodule_desc\x18\x03 \x01(\x0b\x32-.bilibili.app.dynamic.v1.DynOurCityModuleDescH\x00\x12H\n\rmodule_author\x18\x04 \x01(\x0b\x32/.bilibili.app.dynamic.v1.DynOurCityModuleAuthorH\x00\x12H\n\rmodule_extend\x18\x05 \x01(\x0b\x32/.bilibili.app.dynamic.v1.DynOurCityModuleExtendH\x00\x42\r\n\x0bmodule_item\"\xf1\x01\n\x15\x44ynOurCityModuleCover\x12\x0e\n\x06\x63overs\x18\x01 \x03(\t\x12\r\n\x05style\x18\x02 \x01(\x05\x12\x19\n\x11\x63over_left_icon_1\x18\x03 \x01(\x05\x12\x19\n\x11\x63over_left_text_1\x18\x04 \x01(\t\x12\x19\n\x11\x63over_left_icon_2\x18\x05 \x01(\x05\x12\x19\n\x11\x63over_left_text_2\x18\x06 \x01(\t\x12\x19\n\x11\x63over_left_text_3\x18\x07 \x01(\t\x12\x32\n\x05\x62\x61\x64ge\x18\x08 \x03(\x0b\x32#.bilibili.app.dynamic.v1.VideoBadge\"$\n\x14\x44ynOurCityModuleDesc\x12\x0c\n\x04\x64\x65sc\x18\x01 \x01(\t\"N\n\x16\x44ynOurCityModuleAuthor\x12\x0b\n\x03mid\x18\x01 \x01(\x03\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04\x66\x61\x63\x65\x18\x03 \x01(\t\x12\x0b\n\x03uri\x18\x04 \x01(\t\"z\n\x16\x44ynOurCityModuleExtend\x12\x0c\n\x04type\x18\x01 \x01(\t\x12H\n\nextend_lbs\x18\x02 \x01(\x0b\x32\x32.bilibili.app.dynamic.v1.DynOurCityModuleExtendLBSH\x00\x42\x08\n\x06\x65xtend\"W\n\x19\x44ynOurCityModuleExtendLBS\x12\r\n\x05title\x18\x01 \x01(\t\x12\x0b\n\x03uri\x18\x02 \x01(\t\x12\x0c\n\x04icon\x18\x03 \x01(\t\x12\x10\n\x08poi_type\x18\x04 \x01(\x05\"l\n\x0fModuleDynUpList\x12\x14\n\x0cmodule_title\x18\x01 \x01(\t\x12\x10\n\x08show_all\x18\x02 \x01(\t\x12\x31\n\x04list\x18\x03 \x03(\x0b\x32#.bilibili.app.dynamic.v1.UpListItem\"I\n\nUpListItem\x12\x12\n\nhas_update\x18\x01 \x01(\x05\x12\x0c\n\x04\x66\x61\x63\x65\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x0b\n\x03uid\x18\x04 \x01(\x03\"`\n\x10ModuleFollowList\x12\x15\n\rview_all_link\x18\x01 \x01(\t\x12\x35\n\x04list\x18\x02 \x03(\x0b\x32\'.bilibili.app.dynamic.v1.FollowListItem\"~\n\x0e\x46ollowListItem\x12\x11\n\tseason_id\x18\x01 \x01(\x05\x12\r\n\x05title\x18\x02 \x01(\t\x12\r\n\x05\x63over\x18\x03 \x01(\t\x12\x0b\n\x03url\x18\x04 \x01(\t\x12.\n\x06new_ep\x18\x05 \x01(\x0b\x32\x1e.bilibili.app.dynamic.v1.NewEP\"6\n\x05NewEP\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x12\n\nindex_show\x18\x02 \x01(\t\x12\r\n\x05\x63over\x18\x03 \x01(\t\"\xbe\x01\n\x13\x44ynVideoPersonalReq\x12\x16\n\x0eteenagers_mode\x18\x01 \x01(\x05\x12\x10\n\x08host_uid\x18\x02 \x01(\x03\x12\x0e\n\x06offset\x18\x03 \x01(\t\x12\x0c\n\x04page\x18\x04 \x01(\x05\x12\x12\n\nis_preload\x18\x05 \x01(\x05\x12\n\n\x02qn\x18\x06 \x01(\x05\x12\r\n\x05\x66nver\x18\x07 \x01(\x05\x12\r\n\x05\x66nval\x18\x08 \x01(\x05\x12\x12\n\nforce_host\x18\t \x01(\x05\x12\r\n\x05\x66ourk\x18\n \x01(\x05\"\x82\x01\n\x15\x44ynVideoPersonalReply\x12\x32\n\x04list\x18\x01 \x03(\x0b\x32$.bilibili.app.dynamic.v1.DynamicItem\x12\x0e\n\x06offset\x18\x02 \x01(\t\x12\x10\n\x08has_more\x18\x03 \x01(\x05\x12\x13\n\x0bread_offset\x18\x04 \x01(\t\"8\n\x0f\x44ynUpdOffsetReq\x12\x10\n\x08host_uid\x18\x01 \x01(\x03\x12\x13\n\x0bread_offset\x18\x02 \x01(\t\";\n\tPGCSeason\x12\x11\n\tis_finish\x18\x01 \x01(\x05\x12\r\n\x05title\x18\x02 \x01(\t\x12\x0c\n\x04type\x18\x03 \x01(\x05\"C\n\tDynRedReq\x12\x36\n\ntab_offset\x18\x01 \x03(\x0b\x32\".bilibili.app.dynamic.v1.TabOffset\"(\n\tTabOffset\x12\x0b\n\x03tab\x18\x01 \x01(\x05\x12\x0e\n\x06offset\x18\x02 \x01(\t\"o\n\x0b\x44ynRedReply\x12\x10\n\x08red_type\x18\x01 \x01(\t\x12\x39\n\x0c\x64yn_red_item\x18\x02 \x01(\x0b\x32#.bilibili.app.dynamic.v1.DynRedItem\x12\x13\n\x0b\x64\x65\x66\x61ult_tab\x18\x03 \x01(\t\"\x1b\n\nDynRedItem\x12\r\n\x05\x63ount\x18\x01 \x01(\x04\"A\n\x11MixUpListLiveItem\x12\x0e\n\x06status\x18\x01 \x01(\x08\x12\x0f\n\x07room_id\x18\x02 \x01(\x03\x12\x0b\n\x03uri\x18\x03 \x01(\t\"\xc7\x02\n\rMixUpListItem\x12\x0b\n\x03uid\x18\x01 \x01(\x03\x12\x19\n\x11special_attention\x18\x02 \x01(\x05\x12\x14\n\x0creddot_state\x18\x03 \x01(\x05\x12=\n\tlive_info\x18\x04 \x01(\x0b\x32*.bilibili.app.dynamic.v1.MixUpListLiveItem\x12\x0c\n\x04name\x18\x05 \x01(\t\x12\x0c\n\x04\x66\x61\x63\x65\x18\x06 \x01(\t\x12\x39\n\x08official\x18\x07 \x01(\x0b\x32\'.bilibili.app.dynamic.v1.OfficialVerify\x12-\n\x03vip\x18\x08 \x01(\x0b\x32 .bilibili.app.dynamic.v1.VipInfo\x12\x33\n\x08relation\x18\t \x01(\x0b\x32!.bilibili.app.dynamic.v1.Relation\"o\n\x19\x44ynMixUpListViewMoreReply\x12\x35\n\x05items\x18\x01 \x03(\x0b\x32&.bilibili.app.dynamic.v1.MixUpListItem\x12\x1b\n\x13search_default_text\x18\x02 \x01(\t\"%\n\x15\x44ynMixUpListSearchReq\x12\x0c\n\x04name\x18\x01 \x01(\t\"P\n\x17\x44ynMixUpListSearchReply\x12\x35\n\x05items\x18\x01 \x03(\x0b\x32&.bilibili.app.dynamic.v1.MixUpListItem\"z\n\x08Relation\x12\x37\n\x06status\x18\x01 \x01(\x0e\x32\'.bilibili.app.dynamic.v1.RelationStatus\x12\x11\n\tis_follow\x18\x02 \x01(\x05\x12\x13\n\x0bis_followed\x18\x03 \x01(\x05\x12\r\n\x05title\x18\x04 \x01(\t\"V\n\x15OurCityClickReportReq\x12\x12\n\ndynamic_id\x18\x01 \x01(\t\x12\x0f\n\x07\x63ity_id\x18\x02 \x01(\x03\x12\x0b\n\x03lat\x18\x03 \x01(\x01\x12\x0b\n\x03lng\x18\x04 \x01(\x01\"\x19\n\x17OurCityClickReportReply\"5\n\x0bGeoCoderReq\x12\x0b\n\x03lat\x18\x01 \x01(\x01\x12\x0b\n\x03lng\x18\x02 \x01(\x01\x12\x0c\n\x04\x66rom\x18\x03 \x01(\t\"\x98\x01\n\rGeoCoderReply\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\x12\x44\n\x11\x61\x64\x64ress_component\x18\x02 \x01(\x0b\x32).bilibili.app.dynamic.v1.AddressComponent\x12\x30\n\x07\x61\x64_info\x18\x03 \x01(\x0b\x32\x1f.bilibili.app.dynamic.v1.AdInfo\"{\n\x10\x41\x64\x64ressComponent\x12\x0e\n\x06nation\x18\x01 \x01(\t\x12\x10\n\x08province\x18\x02 \x01(\t\x12\x0c\n\x04\x63ity\x18\x03 \x01(\t\x12\x10\n\x08\x64istrict\x18\x04 \x01(\t\x12\x0e\n\x06street\x18\x05 \x01(\t\x12\x15\n\rstreet_number\x18\x06 \x01(\t\"y\n\x06\x41\x64Info\x12\x13\n\x0bnation_code\x18\x01 \x01(\t\x12\x0e\n\x06\x61\x64\x63ode\x18\x02 \x01(\t\x12\x11\n\tcity_code\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12)\n\x03gps\x18\x05 \x01(\x0b\x32\x1c.bilibili.app.dynamic.v1.Gps\"\x1f\n\x03Gps\x12\x0b\n\x03lat\x18\x01 \x01(\x01\x12\x0b\n\x03lng\x18\x02 \x01(\x01*m\n\x08\x46oldType\x12\x10\n\x0c\x46oldTypeZero\x10\x00\x12\x13\n\x0f\x46oldTypePublish\x10\x01\x12\x14\n\x10\x46oldTypeFrequent\x10\x02\x12\x11\n\rFoldTypeUnite\x10\x03\x12\x11\n\rFoldTypeLimit\x10\x04*\xa5\x01\n\x0cVideoSubType\x12\x14\n\x10VideoSubTypeNone\x10\x00\x12\x17\n\x13VideoSubTypeBangumi\x10\x01\x12\x15\n\x11VideoSubTypeMovie\x10\x02\x12\x1b\n\x17VideoSubTypeDocumentary\x10\x03\x12\x18\n\x14VideoSubTypeDomestic\x10\x04\x12\x18\n\x14VideoSubTypeTeleplay\x10\x05*g\n\tMediaType\x12\x11\n\rMediaTypeNone\x10\x00\x12\x10\n\x0cMediaTypeUGC\x10\x01\x12\x10\n\x0cMediaTypePGC\x10\x02\x12\x11\n\rMediaTypeLive\x10\x03\x12\x10\n\x0cMediaTypeVCS\x10\x04*Y\n\nSVideoType\x12\x0c\n\x08TypeNone\x10\x00\x12\x0f\n\x0bTypeDynamic\x10\x01\x12\x14\n\x10TypePopularIndex\x10\x02\x12\x16\n\x12TypePopularHotword\x10\x03*\xc3\x01\n\x0eRelationStatus\x12\x18\n\x14relation_status_none\x10\x00\x12\x1c\n\x18relation_status_nofollow\x10\x01\x12\x1a\n\x16relation_status_follow\x10\x02\x12\x1c\n\x18relation_status_followed\x10\x03\x12\"\n\x1erelation_status_mutual_concern\x10\x04\x12\x1b\n\x17relation_status_special\x10\x05\x32\x8a\n\n\x07\x44ynamic\x12[\n\x08\x44ynVideo\x12$.bilibili.app.dynamic.v1.DynVideoReq\x1a).bilibili.app.dynamic.v1.DynVideoReqReply\x12^\n\nDynDetails\x12&.bilibili.app.dynamic.v1.DynDetailsReq\x1a(.bilibili.app.dynamic.v1.DynDetailsReply\x12R\n\x06SVideo\x12\".bilibili.app.dynamic.v1.SVideoReq\x1a$.bilibili.app.dynamic.v1.SVideoReply\x12R\n\x06\x44ynTab\x12\".bilibili.app.dynamic.v1.DynTabReq\x1a$.bilibili.app.dynamic.v1.DynTabReply\x12\x62\n\x10\x44ynOurCitySwitch\x12,.bilibili.app.dynamic.v1.DynOurCitySwitchReq\x1a .bilibili.app.dynamic.v1.NoReply\x12^\n\nDynOurCity\x12&.bilibili.app.dynamic.v1.DynOurCityReq\x1a(.bilibili.app.dynamic.v1.DynOurCityReply\x12p\n\x10\x44ynVideoPersonal\x12,.bilibili.app.dynamic.v1.DynVideoPersonalReq\x1a..bilibili.app.dynamic.v1.DynVideoPersonalReply\x12Z\n\x0c\x44ynUpdOffset\x12(.bilibili.app.dynamic.v1.DynUpdOffsetReq\x1a .bilibili.app.dynamic.v1.NoReply\x12R\n\x06\x44ynRed\x12\".bilibili.app.dynamic.v1.DynRedReq\x1a$.bilibili.app.dynamic.v1.DynRedReply\x12j\n\x14\x44ynMixUpListViewMore\x12\x1e.bilibili.app.dynamic.v1.NoReq\x1a\x32.bilibili.app.dynamic.v1.DynMixUpListViewMoreReply\x12v\n\x12\x44ynMixUpListSearch\x12..bilibili.app.dynamic.v1.DynMixUpListSearchReq\x1a\x30.bilibili.app.dynamic.v1.DynMixUpListSearchReply\x12v\n\x12OurCityClickReport\x12..bilibili.app.dynamic.v1.OurCityClickReportReq\x1a\x30.bilibili.app.dynamic.v1.OurCityClickReportReply\x12X\n\x08GeoCoder\x12$.bilibili.app.dynamic.v1.GeoCoderReq\x1a&.bilibili.app.dynamic.v1.GeoCoderReplyb\x06proto3')

_FOLDTYPE = DESCRIPTOR.enum_types_by_name['FoldType']
FoldType = enum_type_wrapper.EnumTypeWrapper(_FOLDTYPE)
_VIDEOSUBTYPE = DESCRIPTOR.enum_types_by_name['VideoSubType']
VideoSubType = enum_type_wrapper.EnumTypeWrapper(_VIDEOSUBTYPE)
_MEDIATYPE = DESCRIPTOR.enum_types_by_name['MediaType']
MediaType = enum_type_wrapper.EnumTypeWrapper(_MEDIATYPE)
_SVIDEOTYPE = DESCRIPTOR.enum_types_by_name['SVideoType']
SVideoType = enum_type_wrapper.EnumTypeWrapper(_SVIDEOTYPE)
_RELATIONSTATUS = DESCRIPTOR.enum_types_by_name['RelationStatus']
RelationStatus = enum_type_wrapper.EnumTypeWrapper(_RELATIONSTATUS)
FoldTypeZero = 0
FoldTypePublish = 1
FoldTypeFrequent = 2
FoldTypeUnite = 3
FoldTypeLimit = 4
VideoSubTypeNone = 0
VideoSubTypeBangumi = 1
VideoSubTypeMovie = 2
VideoSubTypeDocumentary = 3
VideoSubTypeDomestic = 4
VideoSubTypeTeleplay = 5
MediaTypeNone = 0
MediaTypeUGC = 1
MediaTypePGC = 2
MediaTypeLive = 3
MediaTypeVCS = 4
TypeNone = 0
TypeDynamic = 1
TypePopularIndex = 2
TypePopularHotword = 3
relation_status_none = 0
relation_status_nofollow = 1
relation_status_follow = 2
relation_status_followed = 3
relation_status_mutual_concern = 4
relation_status_special = 5


_NOREQ = DESCRIPTOR.message_types_by_name['NoReq']
_NOREPLY = DESCRIPTOR.message_types_by_name['NoReply']
_DYNVIDEOREQ = DESCRIPTOR.message_types_by_name['DynVideoReq']
_DYNVIDEOREQREPLY = DESCRIPTOR.message_types_by_name['DynVideoReqReply']
_DYNAMICITEM = DESCRIPTOR.message_types_by_name['DynamicItem']
_MODULE = DESCRIPTOR.message_types_by_name['Module']
_MODULEFOLD = DESCRIPTOR.message_types_by_name['ModuleFold']
_MODULEAUTHOR = DESCRIPTOR.message_types_by_name['ModuleAuthor']
_MODULEDISPUTE = DESCRIPTOR.message_types_by_name['ModuleDispute']
_MODULEDESC = DESCRIPTOR.message_types_by_name['ModuleDesc']
_MODULEDYNAMIC = DESCRIPTOR.message_types_by_name['ModuleDynamic']
_MODULELIKEUSER = DESCRIPTOR.message_types_by_name['ModuleLikeUser']
_MODULESTATE = DESCRIPTOR.message_types_by_name['ModuleState']
_MODULEFORWARD = DESCRIPTOR.message_types_by_name['ModuleForward']
_CARDUGC = DESCRIPTOR.message_types_by_name['CardUGC']
_CARDPGC = DESCRIPTOR.message_types_by_name['CardPGC']
_CARDCURRSEASON = DESCRIPTOR.message_types_by_name['CardCurrSeason']
_CARDCURRBATCH = DESCRIPTOR.message_types_by_name['CardCurrBatch']
_VIDEOBADGE = DESCRIPTOR.message_types_by_name['VideoBadge']
_DIMENSION = DESCRIPTOR.message_types_by_name['Dimension']
_MODULEEXTEND = DESCRIPTOR.message_types_by_name['ModuleExtend']
_EXTEND = DESCRIPTOR.message_types_by_name['Extend']
_EXTINFOGAME = DESCRIPTOR.message_types_by_name['ExtInfoGame']
_EXTINFOTOPIC = DESCRIPTOR.message_types_by_name['ExtInfoTopic']
_EXTINFOLBS = DESCRIPTOR.message_types_by_name['ExtInfoLBS']
_EXTINFOHOT = DESCRIPTOR.message_types_by_name['ExtInfoHot']
_LIKEINFO = DESCRIPTOR.message_types_by_name['LikeInfo']
_LIKEUSER = DESCRIPTOR.message_types_by_name['LikeUser']
_LIKEANIMATION = DESCRIPTOR.message_types_by_name['LikeAnimation']
_DESCRIPTION = DESCRIPTOR.message_types_by_name['Description']
_DECORATECARD = DESCRIPTOR.message_types_by_name['DecorateCard']
_DECOCARDFAN = DESCRIPTOR.message_types_by_name['DecoCardFan']
_USERINFO = DESCRIPTOR.message_types_by_name['UserInfo']
_NAMEPLATE = DESCRIPTOR.message_types_by_name['Nameplate']
_USERPENDANT = DESCRIPTOR.message_types_by_name['UserPendant']
_OFFICIALVERIFY = DESCRIPTOR.message_types_by_name['OfficialVerify']
_VIPINFO = DESCRIPTOR.message_types_by_name['VipInfo']
_VIPLABEL = DESCRIPTOR.message_types_by_name['VipLabel']
_LIVEINFO = DESCRIPTOR.message_types_by_name['LiveInfo']
_DYNDETAILSREQ = DESCRIPTOR.message_types_by_name['DynDetailsReq']
_DYNDETAILSREPLY = DESCRIPTOR.message_types_by_name['DynDetailsReply']
_SVIDEOREQ = DESCRIPTOR.message_types_by_name['SVideoReq']
_SVIDEOREPLY = DESCRIPTOR.message_types_by_name['SVideoReply']
_SVIDEOTOP = DESCRIPTOR.message_types_by_name['SVideoTop']
_PLAYERPRELOADPARAMS = DESCRIPTOR.message_types_by_name['PlayerPreloadParams']
_SVIDEOITEM = DESCRIPTOR.message_types_by_name['SVideoItem']
_SVIDEOMODULE = DESCRIPTOR.message_types_by_name['SVideoModule']
_SVIDEOMODULEAUTHOR = DESCRIPTOR.message_types_by_name['SVideoModuleAuthor']
_SVIDEOMODULEPLAYER = DESCRIPTOR.message_types_by_name['SVideoModulePlayer']
_SVIDEOMODULEDESC = DESCRIPTOR.message_types_by_name['SVideoModuleDesc']
_SVIDEOMODULESTAT = DESCRIPTOR.message_types_by_name['SVideoModuleStat']
_SVIDEOSTATINFO = DESCRIPTOR.message_types_by_name['SVideoStatInfo']
_SHAREINFO = DESCRIPTOR.message_types_by_name['ShareInfo']
_DYNTABREQ = DESCRIPTOR.message_types_by_name['DynTabReq']
_DYNTABREPLY = DESCRIPTOR.message_types_by_name['DynTabReply']
_DYNTAB = DESCRIPTOR.message_types_by_name['DynTab']
_POPUP = DESCRIPTOR.message_types_by_name['Popup']
_DYNOURCITYSWITCHREQ = DESCRIPTOR.message_types_by_name['DynOurCitySwitchReq']
_DYNOURCITYREQ = DESCRIPTOR.message_types_by_name['DynOurCityReq']
_EXPCONF = DESCRIPTOR.message_types_by_name['ExpConf']
_EXP = DESCRIPTOR.message_types_by_name['Exp']
_DYNOURCITYREPLY = DESCRIPTOR.message_types_by_name['DynOurCityReply']
_DYNOURCITYITEM = DESCRIPTOR.message_types_by_name['DynOurCityItem']
_DYNOURCITYMODULE = DESCRIPTOR.message_types_by_name['DynOurCityModule']
_DYNOURCITYMODULECOVER = DESCRIPTOR.message_types_by_name['DynOurCityModuleCover']
_DYNOURCITYMODULEDESC = DESCRIPTOR.message_types_by_name['DynOurCityModuleDesc']
_DYNOURCITYMODULEAUTHOR = DESCRIPTOR.message_types_by_name['DynOurCityModuleAuthor']
_DYNOURCITYMODULEEXTEND = DESCRIPTOR.message_types_by_name['DynOurCityModuleExtend']
_DYNOURCITYMODULEEXTENDLBS = DESCRIPTOR.message_types_by_name['DynOurCityModuleExtendLBS']
_MODULEDYNUPLIST = DESCRIPTOR.message_types_by_name['ModuleDynUpList']
_UPLISTITEM = DESCRIPTOR.message_types_by_name['UpListItem']
_MODULEFOLLOWLIST = DESCRIPTOR.message_types_by_name['ModuleFollowList']
_FOLLOWLISTITEM = DESCRIPTOR.message_types_by_name['FollowListItem']
_NEWEP = DESCRIPTOR.message_types_by_name['NewEP']
_DYNVIDEOPERSONALREQ = DESCRIPTOR.message_types_by_name['DynVideoPersonalReq']
_DYNVIDEOPERSONALREPLY = DESCRIPTOR.message_types_by_name['DynVideoPersonalReply']
_DYNUPDOFFSETREQ = DESCRIPTOR.message_types_by_name['DynUpdOffsetReq']
_PGCSEASON = DESCRIPTOR.message_types_by_name['PGCSeason']
_DYNREDREQ = DESCRIPTOR.message_types_by_name['DynRedReq']
_TABOFFSET = DESCRIPTOR.message_types_by_name['TabOffset']
_DYNREDREPLY = DESCRIPTOR.message_types_by_name['DynRedReply']
_DYNREDITEM = DESCRIPTOR.message_types_by_name['DynRedItem']
_MIXUPLISTLIVEITEM = DESCRIPTOR.message_types_by_name['MixUpListLiveItem']
_MIXUPLISTITEM = DESCRIPTOR.message_types_by_name['MixUpListItem']
_DYNMIXUPLISTVIEWMOREREPLY = DESCRIPTOR.message_types_by_name['DynMixUpListViewMoreReply']
_DYNMIXUPLISTSEARCHREQ = DESCRIPTOR.message_types_by_name['DynMixUpListSearchReq']
_DYNMIXUPLISTSEARCHREPLY = DESCRIPTOR.message_types_by_name['DynMixUpListSearchReply']
_RELATION = DESCRIPTOR.message_types_by_name['Relation']
_OURCITYCLICKREPORTREQ = DESCRIPTOR.message_types_by_name['OurCityClickReportReq']
_OURCITYCLICKREPORTREPLY = DESCRIPTOR.message_types_by_name['OurCityClickReportReply']
_GEOCODERREQ = DESCRIPTOR.message_types_by_name['GeoCoderReq']
_GEOCODERREPLY = DESCRIPTOR.message_types_by_name['GeoCoderReply']
_ADDRESSCOMPONENT = DESCRIPTOR.message_types_by_name['AddressComponent']
_ADINFO = DESCRIPTOR.message_types_by_name['AdInfo']
_GPS = DESCRIPTOR.message_types_by_name['Gps']
NoReq = _reflection.GeneratedProtocolMessageType('NoReq', (_message.Message,), {
  'DESCRIPTOR' : _NOREQ,
  '__module__' : 'bilibili.app.dynamic.v1.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v1.NoReq)
  })
_sym_db.RegisterMessage(NoReq)

NoReply = _reflection.GeneratedProtocolMessageType('NoReply', (_message.Message,), {
  'DESCRIPTOR' : _NOREPLY,
  '__module__' : 'bilibili.app.dynamic.v1.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v1.NoReply)
  })
_sym_db.RegisterMessage(NoReply)

DynVideoReq = _reflection.GeneratedProtocolMessageType('DynVideoReq', (_message.Message,), {
  'DESCRIPTOR' : _DYNVIDEOREQ,
  '__module__' : 'bilibili.app.dynamic.v1.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v1.DynVideoReq)
  })
_sym_db.RegisterMessage(DynVideoReq)

DynVideoReqReply = _reflection.GeneratedProtocolMessageType('DynVideoReqReply', (_message.Message,), {
  'DESCRIPTOR' : _DYNVIDEOREQREPLY,
  '__module__' : 'bilibili.app.dynamic.v1.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v1.DynVideoReqReply)
  })
_sym_db.RegisterMessage(DynVideoReqReply)

DynamicItem = _reflection.GeneratedProtocolMessageType('DynamicItem', (_message.Message,), {
  'DESCRIPTOR' : _DYNAMICITEM,
  '__module__' : 'bilibili.app.dynamic.v1.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v1.DynamicItem)
  })
_sym_db.RegisterMessage(DynamicItem)

Module = _reflection.GeneratedProtocolMessageType('Module', (_message.Message,), {
  'DESCRIPTOR' : _MODULE,
  '__module__' : 'bilibili.app.dynamic.v1.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v1.Module)
  })
_sym_db.RegisterMessage(Module)

ModuleFold = _reflection.GeneratedProtocolMessageType('ModuleFold', (_message.Message,), {
  'DESCRIPTOR' : _MODULEFOLD,
  '__module__' : 'bilibili.app.dynamic.v1.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v1.ModuleFold)
  })
_sym_db.RegisterMessage(ModuleFold)

ModuleAuthor = _reflection.GeneratedProtocolMessageType('ModuleAuthor', (_message.Message,), {
  'DESCRIPTOR' : _MODULEAUTHOR,
  '__module__' : 'bilibili.app.dynamic.v1.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v1.ModuleAuthor)
  })
_sym_db.RegisterMessage(ModuleAuthor)

ModuleDispute = _reflection.GeneratedProtocolMessageType('ModuleDispute', (_message.Message,), {
  'DESCRIPTOR' : _MODULEDISPUTE,
  '__module__' : 'bilibili.app.dynamic.v1.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v1.ModuleDispute)
  })
_sym_db.RegisterMessage(ModuleDispute)

ModuleDesc = _reflection.GeneratedProtocolMessageType('ModuleDesc', (_message.Message,), {
  'DESCRIPTOR' : _MODULEDESC,
  '__module__' : 'bilibili.app.dynamic.v1.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v1.ModuleDesc)
  })
_sym_db.RegisterMessage(ModuleDesc)

ModuleDynamic = _reflection.GeneratedProtocolMessageType('ModuleDynamic', (_message.Message,), {
  'DESCRIPTOR' : _MODULEDYNAMIC,
  '__module__' : 'bilibili.app.dynamic.v1.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v1.ModuleDynamic)
  })
_sym_db.RegisterMessage(ModuleDynamic)

ModuleLikeUser = _reflection.GeneratedProtocolMessageType('ModuleLikeUser', (_message.Message,), {
  'DESCRIPTOR' : _MODULELIKEUSER,
  '__module__' : 'bilibili.app.dynamic.v1.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v1.ModuleLikeUser)
  })
_sym_db.RegisterMessage(ModuleLikeUser)

ModuleState = _reflection.GeneratedProtocolMessageType('ModuleState', (_message.Message,), {
  'DESCRIPTOR' : _MODULESTATE,
  '__module__' : 'bilibili.app.dynamic.v1.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v1.ModuleState)
  })
_sym_db.RegisterMessage(ModuleState)

ModuleForward = _reflection.GeneratedProtocolMessageType('ModuleForward', (_message.Message,), {
  'DESCRIPTOR' : _MODULEFORWARD,
  '__module__' : 'bilibili.app.dynamic.v1.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v1.ModuleForward)
  })
_sym_db.RegisterMessage(ModuleForward)

CardUGC = _reflection.GeneratedProtocolMessageType('CardUGC', (_message.Message,), {
  'DESCRIPTOR' : _CARDUGC,
  '__module__' : 'bilibili.app.dynamic.v1.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v1.CardUGC)
  })
_sym_db.RegisterMessage(CardUGC)

CardPGC = _reflection.GeneratedProtocolMessageType('CardPGC', (_message.Message,), {
  'DESCRIPTOR' : _CARDPGC,
  '__module__' : 'bilibili.app.dynamic.v1.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v1.CardPGC)
  })
_sym_db.RegisterMessage(CardPGC)

CardCurrSeason = _reflection.GeneratedProtocolMessageType('CardCurrSeason', (_message.Message,), {
  'DESCRIPTOR' : _CARDCURRSEASON,
  '__module__' : 'bilibili.app.dynamic.v1.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v1.CardCurrSeason)
  })
_sym_db.RegisterMessage(CardCurrSeason)

CardCurrBatch = _reflection.GeneratedProtocolMessageType('CardCurrBatch', (_message.Message,), {
  'DESCRIPTOR' : _CARDCURRBATCH,
  '__module__' : 'bilibili.app.dynamic.v1.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v1.CardCurrBatch)
  })
_sym_db.RegisterMessage(CardCurrBatch)

VideoBadge = _reflection.GeneratedProtocolMessageType('VideoBadge', (_message.Message,), {
  'DESCRIPTOR' : _VIDEOBADGE,
  '__module__' : 'bilibili.app.dynamic.v1.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v1.VideoBadge)
  })
_sym_db.RegisterMessage(VideoBadge)

Dimension = _reflection.GeneratedProtocolMessageType('Dimension', (_message.Message,), {
  'DESCRIPTOR' : _DIMENSION,
  '__module__' : 'bilibili.app.dynamic.v1.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v1.Dimension)
  })
_sym_db.RegisterMessage(Dimension)

ModuleExtend = _reflection.GeneratedProtocolMessageType('ModuleExtend', (_message.Message,), {
  'DESCRIPTOR' : _MODULEEXTEND,
  '__module__' : 'bilibili.app.dynamic.v1.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v1.ModuleExtend)
  })
_sym_db.RegisterMessage(ModuleExtend)

Extend = _reflection.GeneratedProtocolMessageType('Extend', (_message.Message,), {
  'DESCRIPTOR' : _EXTEND,
  '__module__' : 'bilibili.app.dynamic.v1.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v1.Extend)
  })
_sym_db.RegisterMessage(Extend)

ExtInfoGame = _reflection.GeneratedProtocolMessageType('ExtInfoGame', (_message.Message,), {
  'DESCRIPTOR' : _EXTINFOGAME,
  '__module__' : 'bilibili.app.dynamic.v1.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v1.ExtInfoGame)
  })
_sym_db.RegisterMessage(ExtInfoGame)

ExtInfoTopic = _reflection.GeneratedProtocolMessageType('ExtInfoTopic', (_message.Message,), {
  'DESCRIPTOR' : _EXTINFOTOPIC,
  '__module__' : 'bilibili.app.dynamic.v1.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v1.ExtInfoTopic)
  })
_sym_db.RegisterMessage(ExtInfoTopic)

ExtInfoLBS = _reflection.GeneratedProtocolMessageType('ExtInfoLBS', (_message.Message,), {
  'DESCRIPTOR' : _EXTINFOLBS,
  '__module__' : 'bilibili.app.dynamic.v1.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v1.ExtInfoLBS)
  })
_sym_db.RegisterMessage(ExtInfoLBS)

ExtInfoHot = _reflection.GeneratedProtocolMessageType('ExtInfoHot', (_message.Message,), {
  'DESCRIPTOR' : _EXTINFOHOT,
  '__module__' : 'bilibili.app.dynamic.v1.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v1.ExtInfoHot)
  })
_sym_db.RegisterMessage(ExtInfoHot)

LikeInfo = _reflection.GeneratedProtocolMessageType('LikeInfo', (_message.Message,), {
  'DESCRIPTOR' : _LIKEINFO,
  '__module__' : 'bilibili.app.dynamic.v1.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v1.LikeInfo)
  })
_sym_db.RegisterMessage(LikeInfo)

LikeUser = _reflection.GeneratedProtocolMessageType('LikeUser', (_message.Message,), {
  'DESCRIPTOR' : _LIKEUSER,
  '__module__' : 'bilibili.app.dynamic.v1.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v1.LikeUser)
  })
_sym_db.RegisterMessage(LikeUser)

LikeAnimation = _reflection.GeneratedProtocolMessageType('LikeAnimation', (_message.Message,), {
  'DESCRIPTOR' : _LIKEANIMATION,
  '__module__' : 'bilibili.app.dynamic.v1.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v1.LikeAnimation)
  })
_sym_db.RegisterMessage(LikeAnimation)

Description = _reflection.GeneratedProtocolMessageType('Description', (_message.Message,), {
  'DESCRIPTOR' : _DESCRIPTION,
  '__module__' : 'bilibili.app.dynamic.v1.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v1.Description)
  })
_sym_db.RegisterMessage(Description)

DecorateCard = _reflection.GeneratedProtocolMessageType('DecorateCard', (_message.Message,), {
  'DESCRIPTOR' : _DECORATECARD,
  '__module__' : 'bilibili.app.dynamic.v1.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v1.DecorateCard)
  })
_sym_db.RegisterMessage(DecorateCard)

DecoCardFan = _reflection.GeneratedProtocolMessageType('DecoCardFan', (_message.Message,), {
  'DESCRIPTOR' : _DECOCARDFAN,
  '__module__' : 'bilibili.app.dynamic.v1.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v1.DecoCardFan)
  })
_sym_db.RegisterMessage(DecoCardFan)

UserInfo = _reflection.GeneratedProtocolMessageType('UserInfo', (_message.Message,), {
  'DESCRIPTOR' : _USERINFO,
  '__module__' : 'bilibili.app.dynamic.v1.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v1.UserInfo)
  })
_sym_db.RegisterMessage(UserInfo)

Nameplate = _reflection.GeneratedProtocolMessageType('Nameplate', (_message.Message,), {
  'DESCRIPTOR' : _NAMEPLATE,
  '__module__' : 'bilibili.app.dynamic.v1.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v1.Nameplate)
  })
_sym_db.RegisterMessage(Nameplate)

UserPendant = _reflection.GeneratedProtocolMessageType('UserPendant', (_message.Message,), {
  'DESCRIPTOR' : _USERPENDANT,
  '__module__' : 'bilibili.app.dynamic.v1.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v1.UserPendant)
  })
_sym_db.RegisterMessage(UserPendant)

OfficialVerify = _reflection.GeneratedProtocolMessageType('OfficialVerify', (_message.Message,), {
  'DESCRIPTOR' : _OFFICIALVERIFY,
  '__module__' : 'bilibili.app.dynamic.v1.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v1.OfficialVerify)
  })
_sym_db.RegisterMessage(OfficialVerify)

VipInfo = _reflection.GeneratedProtocolMessageType('VipInfo', (_message.Message,), {
  'DESCRIPTOR' : _VIPINFO,
  '__module__' : 'bilibili.app.dynamic.v1.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v1.VipInfo)
  })
_sym_db.RegisterMessage(VipInfo)

VipLabel = _reflection.GeneratedProtocolMessageType('VipLabel', (_message.Message,), {
  'DESCRIPTOR' : _VIPLABEL,
  '__module__' : 'bilibili.app.dynamic.v1.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v1.VipLabel)
  })
_sym_db.RegisterMessage(VipLabel)

LiveInfo = _reflection.GeneratedProtocolMessageType('LiveInfo', (_message.Message,), {
  'DESCRIPTOR' : _LIVEINFO,
  '__module__' : 'bilibili.app.dynamic.v1.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v1.LiveInfo)
  })
_sym_db.RegisterMessage(LiveInfo)

DynDetailsReq = _reflection.GeneratedProtocolMessageType('DynDetailsReq', (_message.Message,), {
  'DESCRIPTOR' : _DYNDETAILSREQ,
  '__module__' : 'bilibili.app.dynamic.v1.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v1.DynDetailsReq)
  })
_sym_db.RegisterMessage(DynDetailsReq)

DynDetailsReply = _reflection.GeneratedProtocolMessageType('DynDetailsReply', (_message.Message,), {
  'DESCRIPTOR' : _DYNDETAILSREPLY,
  '__module__' : 'bilibili.app.dynamic.v1.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v1.DynDetailsReply)
  })
_sym_db.RegisterMessage(DynDetailsReply)

SVideoReq = _reflection.GeneratedProtocolMessageType('SVideoReq', (_message.Message,), {
  'DESCRIPTOR' : _SVIDEOREQ,
  '__module__' : 'bilibili.app.dynamic.v1.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v1.SVideoReq)
  })
_sym_db.RegisterMessage(SVideoReq)

SVideoReply = _reflection.GeneratedProtocolMessageType('SVideoReply', (_message.Message,), {
  'DESCRIPTOR' : _SVIDEOREPLY,
  '__module__' : 'bilibili.app.dynamic.v1.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v1.SVideoReply)
  })
_sym_db.RegisterMessage(SVideoReply)

SVideoTop = _reflection.GeneratedProtocolMessageType('SVideoTop', (_message.Message,), {
  'DESCRIPTOR' : _SVIDEOTOP,
  '__module__' : 'bilibili.app.dynamic.v1.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v1.SVideoTop)
  })
_sym_db.RegisterMessage(SVideoTop)

PlayerPreloadParams = _reflection.GeneratedProtocolMessageType('PlayerPreloadParams', (_message.Message,), {
  'DESCRIPTOR' : _PLAYERPRELOADPARAMS,
  '__module__' : 'bilibili.app.dynamic.v1.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v1.PlayerPreloadParams)
  })
_sym_db.RegisterMessage(PlayerPreloadParams)

SVideoItem = _reflection.GeneratedProtocolMessageType('SVideoItem', (_message.Message,), {
  'DESCRIPTOR' : _SVIDEOITEM,
  '__module__' : 'bilibili.app.dynamic.v1.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v1.SVideoItem)
  })
_sym_db.RegisterMessage(SVideoItem)

SVideoModule = _reflection.GeneratedProtocolMessageType('SVideoModule', (_message.Message,), {
  'DESCRIPTOR' : _SVIDEOMODULE,
  '__module__' : 'bilibili.app.dynamic.v1.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v1.SVideoModule)
  })
_sym_db.RegisterMessage(SVideoModule)

SVideoModuleAuthor = _reflection.GeneratedProtocolMessageType('SVideoModuleAuthor', (_message.Message,), {
  'DESCRIPTOR' : _SVIDEOMODULEAUTHOR,
  '__module__' : 'bilibili.app.dynamic.v1.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v1.SVideoModuleAuthor)
  })
_sym_db.RegisterMessage(SVideoModuleAuthor)

SVideoModulePlayer = _reflection.GeneratedProtocolMessageType('SVideoModulePlayer', (_message.Message,), {
  'DESCRIPTOR' : _SVIDEOMODULEPLAYER,
  '__module__' : 'bilibili.app.dynamic.v1.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v1.SVideoModulePlayer)
  })
_sym_db.RegisterMessage(SVideoModulePlayer)

SVideoModuleDesc = _reflection.GeneratedProtocolMessageType('SVideoModuleDesc', (_message.Message,), {
  'DESCRIPTOR' : _SVIDEOMODULEDESC,
  '__module__' : 'bilibili.app.dynamic.v1.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v1.SVideoModuleDesc)
  })
_sym_db.RegisterMessage(SVideoModuleDesc)

SVideoModuleStat = _reflection.GeneratedProtocolMessageType('SVideoModuleStat', (_message.Message,), {
  'DESCRIPTOR' : _SVIDEOMODULESTAT,
  '__module__' : 'bilibili.app.dynamic.v1.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v1.SVideoModuleStat)
  })
_sym_db.RegisterMessage(SVideoModuleStat)

SVideoStatInfo = _reflection.GeneratedProtocolMessageType('SVideoStatInfo', (_message.Message,), {
  'DESCRIPTOR' : _SVIDEOSTATINFO,
  '__module__' : 'bilibili.app.dynamic.v1.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v1.SVideoStatInfo)
  })
_sym_db.RegisterMessage(SVideoStatInfo)

ShareInfo = _reflection.GeneratedProtocolMessageType('ShareInfo', (_message.Message,), {
  'DESCRIPTOR' : _SHAREINFO,
  '__module__' : 'bilibili.app.dynamic.v1.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v1.ShareInfo)
  })
_sym_db.RegisterMessage(ShareInfo)

DynTabReq = _reflection.GeneratedProtocolMessageType('DynTabReq', (_message.Message,), {
  'DESCRIPTOR' : _DYNTABREQ,
  '__module__' : 'bilibili.app.dynamic.v1.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v1.DynTabReq)
  })
_sym_db.RegisterMessage(DynTabReq)

DynTabReply = _reflection.GeneratedProtocolMessageType('DynTabReply', (_message.Message,), {
  'DESCRIPTOR' : _DYNTABREPLY,
  '__module__' : 'bilibili.app.dynamic.v1.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v1.DynTabReply)
  })
_sym_db.RegisterMessage(DynTabReply)

DynTab = _reflection.GeneratedProtocolMessageType('DynTab', (_message.Message,), {
  'DESCRIPTOR' : _DYNTAB,
  '__module__' : 'bilibili.app.dynamic.v1.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v1.DynTab)
  })
_sym_db.RegisterMessage(DynTab)

Popup = _reflection.GeneratedProtocolMessageType('Popup', (_message.Message,), {
  'DESCRIPTOR' : _POPUP,
  '__module__' : 'bilibili.app.dynamic.v1.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v1.Popup)
  })
_sym_db.RegisterMessage(Popup)

DynOurCitySwitchReq = _reflection.GeneratedProtocolMessageType('DynOurCitySwitchReq', (_message.Message,), {
  'DESCRIPTOR' : _DYNOURCITYSWITCHREQ,
  '__module__' : 'bilibili.app.dynamic.v1.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v1.DynOurCitySwitchReq)
  })
_sym_db.RegisterMessage(DynOurCitySwitchReq)

DynOurCityReq = _reflection.GeneratedProtocolMessageType('DynOurCityReq', (_message.Message,), {
  'DESCRIPTOR' : _DYNOURCITYREQ,
  '__module__' : 'bilibili.app.dynamic.v1.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v1.DynOurCityReq)
  })
_sym_db.RegisterMessage(DynOurCityReq)

ExpConf = _reflection.GeneratedProtocolMessageType('ExpConf', (_message.Message,), {
  'DESCRIPTOR' : _EXPCONF,
  '__module__' : 'bilibili.app.dynamic.v1.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v1.ExpConf)
  })
_sym_db.RegisterMessage(ExpConf)

Exp = _reflection.GeneratedProtocolMessageType('Exp', (_message.Message,), {
  'DESCRIPTOR' : _EXP,
  '__module__' : 'bilibili.app.dynamic.v1.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v1.Exp)
  })
_sym_db.RegisterMessage(Exp)

DynOurCityReply = _reflection.GeneratedProtocolMessageType('DynOurCityReply', (_message.Message,), {
  'DESCRIPTOR' : _DYNOURCITYREPLY,
  '__module__' : 'bilibili.app.dynamic.v1.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v1.DynOurCityReply)
  })
_sym_db.RegisterMessage(DynOurCityReply)

DynOurCityItem = _reflection.GeneratedProtocolMessageType('DynOurCityItem', (_message.Message,), {
  'DESCRIPTOR' : _DYNOURCITYITEM,
  '__module__' : 'bilibili.app.dynamic.v1.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v1.DynOurCityItem)
  })
_sym_db.RegisterMessage(DynOurCityItem)

DynOurCityModule = _reflection.GeneratedProtocolMessageType('DynOurCityModule', (_message.Message,), {
  'DESCRIPTOR' : _DYNOURCITYMODULE,
  '__module__' : 'bilibili.app.dynamic.v1.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v1.DynOurCityModule)
  })
_sym_db.RegisterMessage(DynOurCityModule)

DynOurCityModuleCover = _reflection.GeneratedProtocolMessageType('DynOurCityModuleCover', (_message.Message,), {
  'DESCRIPTOR' : _DYNOURCITYMODULECOVER,
  '__module__' : 'bilibili.app.dynamic.v1.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v1.DynOurCityModuleCover)
  })
_sym_db.RegisterMessage(DynOurCityModuleCover)

DynOurCityModuleDesc = _reflection.GeneratedProtocolMessageType('DynOurCityModuleDesc', (_message.Message,), {
  'DESCRIPTOR' : _DYNOURCITYMODULEDESC,
  '__module__' : 'bilibili.app.dynamic.v1.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v1.DynOurCityModuleDesc)
  })
_sym_db.RegisterMessage(DynOurCityModuleDesc)

DynOurCityModuleAuthor = _reflection.GeneratedProtocolMessageType('DynOurCityModuleAuthor', (_message.Message,), {
  'DESCRIPTOR' : _DYNOURCITYMODULEAUTHOR,
  '__module__' : 'bilibili.app.dynamic.v1.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v1.DynOurCityModuleAuthor)
  })
_sym_db.RegisterMessage(DynOurCityModuleAuthor)

DynOurCityModuleExtend = _reflection.GeneratedProtocolMessageType('DynOurCityModuleExtend', (_message.Message,), {
  'DESCRIPTOR' : _DYNOURCITYMODULEEXTEND,
  '__module__' : 'bilibili.app.dynamic.v1.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v1.DynOurCityModuleExtend)
  })
_sym_db.RegisterMessage(DynOurCityModuleExtend)

DynOurCityModuleExtendLBS = _reflection.GeneratedProtocolMessageType('DynOurCityModuleExtendLBS', (_message.Message,), {
  'DESCRIPTOR' : _DYNOURCITYMODULEEXTENDLBS,
  '__module__' : 'bilibili.app.dynamic.v1.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v1.DynOurCityModuleExtendLBS)
  })
_sym_db.RegisterMessage(DynOurCityModuleExtendLBS)

ModuleDynUpList = _reflection.GeneratedProtocolMessageType('ModuleDynUpList', (_message.Message,), {
  'DESCRIPTOR' : _MODULEDYNUPLIST,
  '__module__' : 'bilibili.app.dynamic.v1.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v1.ModuleDynUpList)
  })
_sym_db.RegisterMessage(ModuleDynUpList)

UpListItem = _reflection.GeneratedProtocolMessageType('UpListItem', (_message.Message,), {
  'DESCRIPTOR' : _UPLISTITEM,
  '__module__' : 'bilibili.app.dynamic.v1.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v1.UpListItem)
  })
_sym_db.RegisterMessage(UpListItem)

ModuleFollowList = _reflection.GeneratedProtocolMessageType('ModuleFollowList', (_message.Message,), {
  'DESCRIPTOR' : _MODULEFOLLOWLIST,
  '__module__' : 'bilibili.app.dynamic.v1.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v1.ModuleFollowList)
  })
_sym_db.RegisterMessage(ModuleFollowList)

FollowListItem = _reflection.GeneratedProtocolMessageType('FollowListItem', (_message.Message,), {
  'DESCRIPTOR' : _FOLLOWLISTITEM,
  '__module__' : 'bilibili.app.dynamic.v1.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v1.FollowListItem)
  })
_sym_db.RegisterMessage(FollowListItem)

NewEP = _reflection.GeneratedProtocolMessageType('NewEP', (_message.Message,), {
  'DESCRIPTOR' : _NEWEP,
  '__module__' : 'bilibili.app.dynamic.v1.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v1.NewEP)
  })
_sym_db.RegisterMessage(NewEP)

DynVideoPersonalReq = _reflection.GeneratedProtocolMessageType('DynVideoPersonalReq', (_message.Message,), {
  'DESCRIPTOR' : _DYNVIDEOPERSONALREQ,
  '__module__' : 'bilibili.app.dynamic.v1.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v1.DynVideoPersonalReq)
  })
_sym_db.RegisterMessage(DynVideoPersonalReq)

DynVideoPersonalReply = _reflection.GeneratedProtocolMessageType('DynVideoPersonalReply', (_message.Message,), {
  'DESCRIPTOR' : _DYNVIDEOPERSONALREPLY,
  '__module__' : 'bilibili.app.dynamic.v1.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v1.DynVideoPersonalReply)
  })
_sym_db.RegisterMessage(DynVideoPersonalReply)

DynUpdOffsetReq = _reflection.GeneratedProtocolMessageType('DynUpdOffsetReq', (_message.Message,), {
  'DESCRIPTOR' : _DYNUPDOFFSETREQ,
  '__module__' : 'bilibili.app.dynamic.v1.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v1.DynUpdOffsetReq)
  })
_sym_db.RegisterMessage(DynUpdOffsetReq)

PGCSeason = _reflection.GeneratedProtocolMessageType('PGCSeason', (_message.Message,), {
  'DESCRIPTOR' : _PGCSEASON,
  '__module__' : 'bilibili.app.dynamic.v1.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v1.PGCSeason)
  })
_sym_db.RegisterMessage(PGCSeason)

DynRedReq = _reflection.GeneratedProtocolMessageType('DynRedReq', (_message.Message,), {
  'DESCRIPTOR' : _DYNREDREQ,
  '__module__' : 'bilibili.app.dynamic.v1.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v1.DynRedReq)
  })
_sym_db.RegisterMessage(DynRedReq)

TabOffset = _reflection.GeneratedProtocolMessageType('TabOffset', (_message.Message,), {
  'DESCRIPTOR' : _TABOFFSET,
  '__module__' : 'bilibili.app.dynamic.v1.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v1.TabOffset)
  })
_sym_db.RegisterMessage(TabOffset)

DynRedReply = _reflection.GeneratedProtocolMessageType('DynRedReply', (_message.Message,), {
  'DESCRIPTOR' : _DYNREDREPLY,
  '__module__' : 'bilibili.app.dynamic.v1.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v1.DynRedReply)
  })
_sym_db.RegisterMessage(DynRedReply)

DynRedItem = _reflection.GeneratedProtocolMessageType('DynRedItem', (_message.Message,), {
  'DESCRIPTOR' : _DYNREDITEM,
  '__module__' : 'bilibili.app.dynamic.v1.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v1.DynRedItem)
  })
_sym_db.RegisterMessage(DynRedItem)

MixUpListLiveItem = _reflection.GeneratedProtocolMessageType('MixUpListLiveItem', (_message.Message,), {
  'DESCRIPTOR' : _MIXUPLISTLIVEITEM,
  '__module__' : 'bilibili.app.dynamic.v1.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v1.MixUpListLiveItem)
  })
_sym_db.RegisterMessage(MixUpListLiveItem)

MixUpListItem = _reflection.GeneratedProtocolMessageType('MixUpListItem', (_message.Message,), {
  'DESCRIPTOR' : _MIXUPLISTITEM,
  '__module__' : 'bilibili.app.dynamic.v1.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v1.MixUpListItem)
  })
_sym_db.RegisterMessage(MixUpListItem)

DynMixUpListViewMoreReply = _reflection.GeneratedProtocolMessageType('DynMixUpListViewMoreReply', (_message.Message,), {
  'DESCRIPTOR' : _DYNMIXUPLISTVIEWMOREREPLY,
  '__module__' : 'bilibili.app.dynamic.v1.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v1.DynMixUpListViewMoreReply)
  })
_sym_db.RegisterMessage(DynMixUpListViewMoreReply)

DynMixUpListSearchReq = _reflection.GeneratedProtocolMessageType('DynMixUpListSearchReq', (_message.Message,), {
  'DESCRIPTOR' : _DYNMIXUPLISTSEARCHREQ,
  '__module__' : 'bilibili.app.dynamic.v1.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v1.DynMixUpListSearchReq)
  })
_sym_db.RegisterMessage(DynMixUpListSearchReq)

DynMixUpListSearchReply = _reflection.GeneratedProtocolMessageType('DynMixUpListSearchReply', (_message.Message,), {
  'DESCRIPTOR' : _DYNMIXUPLISTSEARCHREPLY,
  '__module__' : 'bilibili.app.dynamic.v1.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v1.DynMixUpListSearchReply)
  })
_sym_db.RegisterMessage(DynMixUpListSearchReply)

Relation = _reflection.GeneratedProtocolMessageType('Relation', (_message.Message,), {
  'DESCRIPTOR' : _RELATION,
  '__module__' : 'bilibili.app.dynamic.v1.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v1.Relation)
  })
_sym_db.RegisterMessage(Relation)

OurCityClickReportReq = _reflection.GeneratedProtocolMessageType('OurCityClickReportReq', (_message.Message,), {
  'DESCRIPTOR' : _OURCITYCLICKREPORTREQ,
  '__module__' : 'bilibili.app.dynamic.v1.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v1.OurCityClickReportReq)
  })
_sym_db.RegisterMessage(OurCityClickReportReq)

OurCityClickReportReply = _reflection.GeneratedProtocolMessageType('OurCityClickReportReply', (_message.Message,), {
  'DESCRIPTOR' : _OURCITYCLICKREPORTREPLY,
  '__module__' : 'bilibili.app.dynamic.v1.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v1.OurCityClickReportReply)
  })
_sym_db.RegisterMessage(OurCityClickReportReply)

GeoCoderReq = _reflection.GeneratedProtocolMessageType('GeoCoderReq', (_message.Message,), {
  'DESCRIPTOR' : _GEOCODERREQ,
  '__module__' : 'bilibili.app.dynamic.v1.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v1.GeoCoderReq)
  })
_sym_db.RegisterMessage(GeoCoderReq)

GeoCoderReply = _reflection.GeneratedProtocolMessageType('GeoCoderReply', (_message.Message,), {
  'DESCRIPTOR' : _GEOCODERREPLY,
  '__module__' : 'bilibili.app.dynamic.v1.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v1.GeoCoderReply)
  })
_sym_db.RegisterMessage(GeoCoderReply)

AddressComponent = _reflection.GeneratedProtocolMessageType('AddressComponent', (_message.Message,), {
  'DESCRIPTOR' : _ADDRESSCOMPONENT,
  '__module__' : 'bilibili.app.dynamic.v1.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v1.AddressComponent)
  })
_sym_db.RegisterMessage(AddressComponent)

AdInfo = _reflection.GeneratedProtocolMessageType('AdInfo', (_message.Message,), {
  'DESCRIPTOR' : _ADINFO,
  '__module__' : 'bilibili.app.dynamic.v1.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v1.AdInfo)
  })
_sym_db.RegisterMessage(AdInfo)

Gps = _reflection.GeneratedProtocolMessageType('Gps', (_message.Message,), {
  'DESCRIPTOR' : _GPS,
  '__module__' : 'bilibili.app.dynamic.v1.dynamic_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.dynamic.v1.Gps)
  })
_sym_db.RegisterMessage(Gps)

_DYNAMIC = DESCRIPTOR.services_by_name['Dynamic']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _FOLDTYPE._serialized_start=12510
  _FOLDTYPE._serialized_end=12619
  _VIDEOSUBTYPE._serialized_start=12622
  _VIDEOSUBTYPE._serialized_end=12787
  _MEDIATYPE._serialized_start=12789
  _MEDIATYPE._serialized_end=12892
  _SVIDEOTYPE._serialized_start=12894
  _SVIDEOTYPE._serialized_end=12983
  _RELATIONSTATUS._serialized_start=12986
  _RELATIONSTATUS._serialized_end=13181
  _NOREQ._serialized_start=116
  _NOREQ._serialized_end=123
  _NOREPLY._serialized_start=125
  _NOREPLY._serialized_end=134
  _DYNVIDEOREQ._serialized_start=137
  _DYNVIDEOREQ._serialized_end=328
  _DYNVIDEOREQREPLY._serialized_start=331
  _DYNVIDEOREQREPLY._serialized_end=488
  _DYNAMICITEM._serialized_start=491
  _DYNAMICITEM._serialized_end=671
  _MODULE._serialized_start=674
  _MODULE._serialized_end=1433
  _MODULEFOLD._serialized_start=1436
  _MODULEFOLD._serialized_end=1611
  _MODULEAUTHOR._serialized_start=1614
  _MODULEAUTHOR._serialized_end=1779
  _MODULEDISPUTE._serialized_start=1781
  _MODULEDISPUTE._serialized_end=1838
  _MODULEDESC._serialized_start=1840
  _MODULEDESC._serialized_end=1904
  _MODULEDYNAMIC._serialized_start=1907
  _MODULEDYNAMIC._serialized_end=2193
  _MODULELIKEUSER._serialized_start=2195
  _MODULELIKEUSER._serialized_end=2288
  _MODULESTATE._serialized_start=2291
  _MODULESTATE._serialized_end=2443
  _MODULEFORWARD._serialized_start=2445
  _MODULEFORWARD._serialized_end=2529
  _CARDUGC._serialized_start=2532
  _CARDUGC._serialized_end=2873
  _CARDPGC._serialized_start=2876
  _CARDPGC._serialized_end=3378
  _CARDCURRSEASON._serialized_start=3381
  _CARDCURRSEASON._serialized_end=3522
  _CARDCURRBATCH._serialized_start=3525
  _CARDCURRBATCH._serialized_end=3667
  _VIDEOBADGE._serialized_start=3670
  _VIDEOBADGE._serialized_end=3852
  _DIMENSION._serialized_start=3854
  _DIMENSION._serialized_end=3912
  _MODULEEXTEND._serialized_start=3914
  _MODULEEXTEND._serialized_end=3977
  _EXTEND._serialized_start=3980
  _EXTEND._serialized_end=4262
  _EXTINFOGAME._serialized_start=4264
  _EXTINFOGAME._serialized_end=4319
  _EXTINFOTOPIC._serialized_start=4321
  _EXTINFOTOPIC._serialized_end=4377
  _EXTINFOLBS._serialized_start=4379
  _EXTINFOLBS._serialized_end=4451
  _EXTINFOHOT._serialized_start=4453
  _EXTINFOHOT._serialized_end=4507
  _LIKEINFO._serialized_start=4509
  _LIKEINFO._serialized_end=4595
  _LIKEUSER._serialized_start=4597
  _LIKEUSER._serialized_end=4648
  _LIKEANIMATION._serialized_start=4650
  _LIKEANIMATION._serialized_end=4729
  _DESCRIPTION._serialized_start=4731
  _DESCRIPTION._serialized_end=4825
  _DECORATECARD._serialized_start=4827
  _DECORATECARD._serialized_end=4940
  _DECOCARDFAN._serialized_start=4942
  _DECOCARDFAN._serialized_end=5002
  _USERINFO._serialized_start=5005
  _USERINFO._serialized_end=5334
  _NAMEPLATE._serialized_start=5336
  _NAMEPLATE._serialized_end=5444
  _USERPENDANT._serialized_start=5446
  _USERPENDANT._serialized_end=5517
  _OFFICIALVERIFY._serialized_start=5519
  _OFFICIALVERIFY._serialized_end=5581
  _VIPINFO._serialized_start=5583
  _VIPINFO._serialized_end=5710
  _VIPLABEL._serialized_start=5712
  _VIPLABEL._serialized_end=5736
  _LIVEINFO._serialized_start=5738
  _LIVEINFO._serialized_end=5780
  _DYNDETAILSREQ._serialized_start=5783
  _DYNDETAILSREQ._serialized_end=5920
  _DYNDETAILSREPLY._serialized_start=5922
  _DYNDETAILSREPLY._serialized_end=5991
  _SVIDEOREQ._serialized_start=5994
  _SVIDEOREQ._serialized_end=6355
  _SVIDEOREPLY._serialized_start=6358
  _SVIDEOREPLY._serialized_end=6505
  _SVIDEOTOP._serialized_start=6507
  _SVIDEOTOP._serialized_end=6547
  _PLAYERPRELOADPARAMS._serialized_start=6549
  _PLAYERPRELOADPARAMS._serialized_end=6647
  _SVIDEOITEM._serialized_start=6649
  _SVIDEOITEM._serialized_end=6771
  _SVIDEOMODULE._serialized_start=6774
  _SVIDEOMODULE._serialized_end=7096
  _SVIDEOMODULEAUTHOR._serialized_start=7098
  _SVIDEOMODULEAUTHOR._serialized_end=7212
  _SVIDEOMODULEPLAYER._serialized_start=7215
  _SVIDEOMODULEPLAYER._serialized_end=7377
  _SVIDEOMODULEDESC._serialized_start=7379
  _SVIDEOMODULEDESC._serialized_end=7424
  _SVIDEOMODULESTAT._serialized_start=7427
  _SVIDEOMODULESTAT._serialized_end=7561
  _SVIDEOSTATINFO._serialized_start=7563
  _SVIDEOSTATINFO._serialized_end=7637
  _SHAREINFO._serialized_start=7639
  _SHAREINFO._serialized_end=7752
  _DYNTABREQ._serialized_start=7754
  _DYNTABREQ._serialized_end=7789
  _DYNTABREPLY._serialized_start=7791
  _DYNTABREPLY._serialized_end=7854
  _DYNTAB._serialized_start=7857
  _DYNTAB._serialized_end=8088
  _POPUP._serialized_start=8090
  _POPUP._serialized_end=8139
  _DYNOURCITYSWITCHREQ._serialized_start=8141
  _DYNOURCITYSWITCHREQ._serialized_end=8178
  _DYNOURCITYREQ._serialized_start=8181
  _DYNOURCITYREQ._serialized_end=8576
  _EXPCONF._serialized_start=8578
  _EXPCONF._serialized_end=8651
  _EXP._serialized_start=8653
  _EXP._serialized_end=8695
  _DYNOURCITYREPLY._serialized_start=8698
  _DYNOURCITYREPLY._serialized_end=8900
  _DYNOURCITYITEM._serialized_start=8903
  _DYNOURCITYITEM._serialized_end=9060
  _DYNOURCITYMODULE._serialized_start=9063
  _DYNOURCITYMODULE._serialized_end=9407
  _DYNOURCITYMODULECOVER._serialized_start=9410
  _DYNOURCITYMODULECOVER._serialized_end=9651
  _DYNOURCITYMODULEDESC._serialized_start=9653
  _DYNOURCITYMODULEDESC._serialized_end=9689
  _DYNOURCITYMODULEAUTHOR._serialized_start=9691
  _DYNOURCITYMODULEAUTHOR._serialized_end=9769
  _DYNOURCITYMODULEEXTEND._serialized_start=9771
  _DYNOURCITYMODULEEXTEND._serialized_end=9893
  _DYNOURCITYMODULEEXTENDLBS._serialized_start=9895
  _DYNOURCITYMODULEEXTENDLBS._serialized_end=9982
  _MODULEDYNUPLIST._serialized_start=9984
  _MODULEDYNUPLIST._serialized_end=10092
  _UPLISTITEM._serialized_start=10094
  _UPLISTITEM._serialized_end=10167
  _MODULEFOLLOWLIST._serialized_start=10169
  _MODULEFOLLOWLIST._serialized_end=10265
  _FOLLOWLISTITEM._serialized_start=10267
  _FOLLOWLISTITEM._serialized_end=10393
  _NEWEP._serialized_start=10395
  _NEWEP._serialized_end=10449
  _DYNVIDEOPERSONALREQ._serialized_start=10452
  _DYNVIDEOPERSONALREQ._serialized_end=10642
  _DYNVIDEOPERSONALREPLY._serialized_start=10645
  _DYNVIDEOPERSONALREPLY._serialized_end=10775
  _DYNUPDOFFSETREQ._serialized_start=10777
  _DYNUPDOFFSETREQ._serialized_end=10833
  _PGCSEASON._serialized_start=10835
  _PGCSEASON._serialized_end=10894
  _DYNREDREQ._serialized_start=10896
  _DYNREDREQ._serialized_end=10963
  _TABOFFSET._serialized_start=10965
  _TABOFFSET._serialized_end=11005
  _DYNREDREPLY._serialized_start=11007
  _DYNREDREPLY._serialized_end=11118
  _DYNREDITEM._serialized_start=11120
  _DYNREDITEM._serialized_end=11147
  _MIXUPLISTLIVEITEM._serialized_start=11149
  _MIXUPLISTLIVEITEM._serialized_end=11214
  _MIXUPLISTITEM._serialized_start=11217
  _MIXUPLISTITEM._serialized_end=11544
  _DYNMIXUPLISTVIEWMOREREPLY._serialized_start=11546
  _DYNMIXUPLISTVIEWMOREREPLY._serialized_end=11657
  _DYNMIXUPLISTSEARCHREQ._serialized_start=11659
  _DYNMIXUPLISTSEARCHREQ._serialized_end=11696
  _DYNMIXUPLISTSEARCHREPLY._serialized_start=11698
  _DYNMIXUPLISTSEARCHREPLY._serialized_end=11778
  _RELATION._serialized_start=11780
  _RELATION._serialized_end=11902
  _OURCITYCLICKREPORTREQ._serialized_start=11904
  _OURCITYCLICKREPORTREQ._serialized_end=11990
  _OURCITYCLICKREPORTREPLY._serialized_start=11992
  _OURCITYCLICKREPORTREPLY._serialized_end=12017
  _GEOCODERREQ._serialized_start=12019
  _GEOCODERREQ._serialized_end=12072
  _GEOCODERREPLY._serialized_start=12075
  _GEOCODERREPLY._serialized_end=12227
  _ADDRESSCOMPONENT._serialized_start=12229
  _ADDRESSCOMPONENT._serialized_end=12352
  _ADINFO._serialized_start=12354
  _ADINFO._serialized_end=12475
  _GPS._serialized_start=12477
  _GPS._serialized_end=12508
  _DYNAMIC._serialized_start=13184
  _DYNAMIC._serialized_end=14474
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class PlayerOnlineReq(google.protobuf.message.Message):
    """获取在线人数-请求"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    AID_FIELD_NUMBER: builtins.int
    CID_FIELD_NUMBER: builtins.int
    PLAY_OPEN_FIELD_NUMBER: builtins.int
    aid: builtins.int
    """稿件 avid"""

    cid: builtins.int
    """视频 cid"""

    play_open: builtins.bool
    """是否在播放中"""

    def __init__(self,
        *,
        aid: builtins.int = ...,
        cid: builtins.int = ...,
        play_open: builtins.bool = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["aid",b"aid","cid",b"cid","play_open",b"play_open"]) -> None: ...
global___PlayerOnlineReq = PlayerOnlineReq

class PlayerOnlineReply(google.protobuf.message.Message):
    """获取在线人数-回复"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    TOTAL_TEXT_FIELD_NUMBER: builtins.int
    SEC_NEXT_FIELD_NUMBER: builtins.int
    BOTTOM_SHOW_FIELD_NUMBER: builtins.int
    SDM_SHOW_FIELD_NUMBER: builtins.int
    SDM_TEXT_FIELD_NUMBER: builtins.int
    total_text: typing.Text
    """"""

    sec_next: builtins.int
    """下次轮询间隔时间"""

    bottom_show: builtins.bool
    """是否底部显示"""

    sdm_show: builtins.bool
    """"""

    sdm_text: typing.Text
    """"""

    def __init__(self,
        *,
        total_text: typing.Text = ...,
        sec_next: builtins.int = ...,
        bottom_show: builtins.bool = ...,
        sdm_show: builtins.bool = ...,
        sdm_text: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["bottom_show",b"bottom_show","sdm_show",b"sdm_show","sdm_text",b"sdm_text","sec_next",b"sec_next","total_text",b"total_text"]) -> None: ...
global___PlayerOnlineReply = PlayerOnlineReply
